@@ -180,7 +180,7 @@ class UI (gconf_wrapper.GConfWrapper):
         self.gsd.connect('puzzle-finished',self.you_win_callback)
         self.main_actions = gtk.ActionGroup('MainActions')        
         self.main_actions.add_actions([
-            ('File',None,'_File'),
+            ('File',None,_('_File')),
             ('New',gtk.STOCK_NEW,None,
              '<Control>n',_('New game'),self.new_cb),
             ('Print',gtk.STOCK_PRINT,None,
@@ -269,7 +269,7 @@ class UI (gconf_wrapper.GConfWrapper):
         
         self.edit_actions = gtk.ActionGroup('EditActions')
         self.edit_actions.add_actions(
-            [('Edit',None,'_Edit'),
+            [('Edit',None,_('_Edit')),
              ('Undo',gtk.STOCK_UNDO,_('_Undo'),'<Control>z',_('Undo last action')),
              ('Redo',gtk.STOCK_REDO,_('_Redo'),'<Shift><Control>z',_('Redo last action')),
              ('Clear',gtk.STOCK_CLEAR,_('_Clear'),'<Control>b',_("Clear entries you've filled in"),self.clear_cb),
@@ -787,13 +787,13 @@ class UI (gconf_wrapper.GConfWrapper):
         about.set_name(APPNAME)
         about.set_version(VERSION)
         about.set_copyright(COPYRIGHT)
-	about.set_license(LICENSE)
+	about.set_license(LICENSE[0] + '\n\n' + LICENSE[1] + '\n\n' +LICENSE[2])
 	about.set_wrap_license(True)
         about.set_comments(DESCRIPTION)
         about.set_authors(AUTHORS)
         about.set_website("http://www.gnome.org/projects/gnome-games/")
         about.set_logo_icon_name("sudoku")
-        about.set_translator_credits(_("translator_credits"))
+        about.set_translator_credits(_("translator-credits"))
         about.set_icon_from_file(ICON_DIR + "/sudoku.png")
         about.connect("response", lambda d, r: d.destroy())
         about.show()
